@@ -1,4 +1,9 @@
-#!/usr/bin/perl
+#!/usr/bin/perl -w
+#
+# This small example program walks the directory tree and draws a
+# directory of the files and directories in the GraphViz distribution.
+#
+# It also shows the use of the GraphViz::No subclass.
 
 use strict;
 use lib '../lib';
@@ -9,13 +14,13 @@ use GraphViz::No;
 
 my $directory = '../';
 
-my $graph = GraphViz::No->new({directed => 0});
+my $graph = GraphViz::No->new(directed => 0);
 
 walk($directory);
 
 sub walk {
   my($dir, $parent) = @_;
-  warn "\nwalk $dir $parent\n";
+#  warn "\nwalk $dir $parent\n";
 
   $graph->add_node($dir) unless defined $parent;
 
@@ -23,20 +28,20 @@ sub walk {
   foreach my $file ($d->read) {
     next if $file =~ /^\./;
     if (-f $dir . $file) {
-      warn "$file in $dir\n";
+      # It's a file!
+#      warn "$file in $dir\n";
       $graph->add_node($dir . $file, label => $file);
       $graph->add_edge($dir => $dir . $file);
     } elsif (-d $dir . $file) {
-      warn "$file in $dir is DIR\n";
+      # It's a directory!
+#      warn "$file in $dir is DIR\n";
       $graph->add_node($dir . $file . '/', label => $file . '/');
       $graph->add_edge($dir => $dir . $file . '/');
       walk($dir . $file . '/', $dir);
     }
   }
-  warn "\n";
+#  warn "\n";
 }
 
 #print $graph->_as_debug;
 $graph->as_png("directories.png");
-
-
